import { Surfaces } from "../../surfaces.js";
import { SDKContextSchema } from "../../sdk/schema.js";
/*
 * The INITIALIZE message is sent when the host has received an initialization event from the
 * surface. It should contain most, if not all, data the surface would need to start begin rendering
 * (e.g. metadata about the extension, authentication credentials, etc.)
 */
import { z } from "zod";
export const UI_EXTENSION_HOST_INITIALIZE_EVENT_TYPE = "NF::EUI_HOST::INITIALIZE";
export const UIExtensionHostInitializeEventSchema = z.object({
    type: z.literal(UI_EXTENSION_HOST_INITIALIZE_EVENT_TYPE),
    data: z.object({
        // Metadata about the current user session
        context: SDKContextSchema,
        // Metadata about the extension
        extension: z.object({
            id: z.string(),
            name: z.string(),
            slug: z.string(),
        }),
        // Routing metadata
        // @deprecated, now located on context.surface.
        surface: z.object({ name: z.nativeEnum(Surfaces) }),
    }),
});
export const createUIExtensionHostInitializeEvent = (data) => ({
    type: UI_EXTENSION_HOST_INITIALIZE_EVENT_TYPE,
    data,
});
//# sourceMappingURL=initialize.js.map