import { z } from "zod";
export * from "./host/main.js";
export * from "./surface/main.js";
/**
 * `UIExtensionEventSchema` is a combined schema that can parse any type of event (both host and
 * surface).
 *
 * In general, you probably don't want to use this--you're likely looking for either
 * `UIExtensionHostEventSchema` or `UIExtensionSurfaceEventSchema`. This can be useful, however, in
 * environments where the "host" and surface run in the same process (e.g. tests, Storybook).
 */
export declare const UIExtensionEventSchema: z.ZodUnion<[z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_HOST::INITIALIZE">;
    data: z.ZodObject<{
        context: z.ZodDiscriminatedUnion<"surface", [z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.TeamConfiguration>;
            siteId: z.ZodNull;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.ConnectConfiguration>;
            configurationId: z.ZodNullable<z.ZodString>;
            dataLayerId: z.ZodNullable<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteAccessConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteGeneralConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteNotificationsConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.VisualEditorConfiguration>;
            configurationId: z.ZodNullable<z.ZodString>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        }>]>;
        extension: z.ZodObject<{
            id: z.ZodString;
            name: z.ZodString;
            slug: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            id: string;
            name: string;
            slug: string;
        }, {
            id: string;
            name: string;
            slug: string;
        }>;
        surface: z.ZodObject<{
            name: z.ZodNativeEnum<typeof import("../surfaces.js").Surfaces>;
        }, "strip", z.ZodTypeAny, {
            name: import("../surfaces.js").Surfaces;
        }, {
            name: import("../surfaces.js").Surfaces;
        }>;
    }, "strip", z.ZodTypeAny, {
        surface: {
            name: import("../surfaces.js").Surfaces;
        };
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
        extension: {
            id: string;
            name: string;
            slug: string;
        };
    }, {
        surface: {
            name: import("../surfaces.js").Surfaces;
        };
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
        extension: {
            id: string;
            name: string;
            slug: string;
        };
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        surface: {
            name: import("../surfaces.js").Surfaces;
        };
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
        extension: {
            id: string;
            name: string;
            slug: string;
        };
    };
    type: "NF::EUI_HOST::INITIALIZE";
}, {
    data: {
        surface: {
            name: import("../surfaces.js").Surfaces;
        };
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
        extension: {
            id: string;
            name: string;
            slug: string;
        };
    };
    type: "NF::EUI_HOST::INITIALIZE";
}>, z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_HOST::REQUEST_DIMENSIONS">;
    data: z.ZodDefault<z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>>;
}, "strip", z.ZodTypeAny, {
    data: {};
    type: "NF::EUI_HOST::REQUEST_DIMENSIONS";
}, {
    type: "NF::EUI_HOST::REQUEST_DIMENSIONS";
    data?: {} | undefined;
}>, z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_HOST::UPDATE_CONTEXT">;
    data: z.ZodObject<{
        context: z.ZodDiscriminatedUnion<"surface", [z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.TeamConfiguration>;
            siteId: z.ZodNull;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.ConnectConfiguration>;
            configurationId: z.ZodNullable<z.ZodString>;
            dataLayerId: z.ZodNullable<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteAccessConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteGeneralConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteNotificationsConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.SiteConfiguration>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        }>, z.ZodObject<{
            auth: z.ZodObject<{
                netlifyToken: z.ZodNullable<z.ZodString>;
                providerToken: z.ZodNullable<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                netlifyToken: string | null;
                providerToken: string | null;
            }, {
                netlifyToken: string | null;
                providerToken: string | null;
            }>;
            teamId: z.ZodString;
            theme: z.ZodEnum<["light", "dark"]>;
            surface: z.ZodLiteral<import("../surfaces.js").Surfaces.VisualEditorConfiguration>;
            configurationId: z.ZodNullable<z.ZodString>;
            siteId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        }, {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        }>]>;
    }, "strip", z.ZodTypeAny, {
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
    }, {
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
    };
    type: "NF::EUI_HOST::UPDATE_CONTEXT";
}, {
    data: {
        context: {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.TeamConfiguration;
            siteId: null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.ConnectConfiguration;
            configurationId: string | null;
            dataLayerId: string | null;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteAccessConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteBuildDeployConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteGeneralConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteNotificationsConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.SiteConfiguration;
            siteId: string;
        } | {
            auth: {
                netlifyToken: string | null;
                providerToken: string | null;
            };
            teamId: string;
            theme: "light" | "dark";
            surface: import("../surfaces.js").Surfaces.VisualEditorConfiguration;
            siteId: string;
            configurationId: string | null;
        };
    };
    type: "NF::EUI_HOST::UPDATE_CONTEXT";
}>]>, z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_SURFACE::CONNECT_PROVIDER">;
    data: z.ZodDefault<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
}, "strip", z.ZodTypeAny, {
    data: {};
    type: "NF::EUI_SURFACE::CONNECT_PROVIDER";
}, {
    type: "NF::EUI_SURFACE::CONNECT_PROVIDER";
    data?: {} | undefined;
}>, z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_SURFACE::DISCONNECT_PROVIDER">;
    data: z.ZodDefault<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
}, "strip", z.ZodTypeAny, {
    data: {};
    type: "NF::EUI_SURFACE::DISCONNECT_PROVIDER";
}, {
    type: "NF::EUI_SURFACE::DISCONNECT_PROVIDER";
    data?: {} | undefined;
}>, z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_SURFACE::INITIALIZE">;
    data: z.ZodDefault<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
}, "strip", z.ZodTypeAny, {
    data: {};
    type: "NF::EUI_SURFACE::INITIALIZE";
}, {
    type: "NF::EUI_SURFACE::INITIALIZE";
    data?: {} | undefined;
}>, z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_SURFACE::NAVIGATE">;
    data: z.ZodObject<{
        hash: z.ZodOptional<z.ZodString>;
        pathname: z.ZodOptional<z.ZodString>;
        search: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        hash?: string | undefined;
        pathname?: string | undefined;
        search?: string | undefined;
    }, {
        hash?: string | undefined;
        pathname?: string | undefined;
        search?: string | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        hash?: string | undefined;
        pathname?: string | undefined;
        search?: string | undefined;
    };
    type: "NF::EUI_SURFACE::NAVIGATE";
}, {
    data: {
        hash?: string | undefined;
        pathname?: string | undefined;
        search?: string | undefined;
    };
    type: "NF::EUI_SURFACE::NAVIGATE";
}>, z.ZodObject<{
    type: z.ZodLiteral<"NF::EUI_SURFACE::REQUEST_DIMENSIONS">;
    data: z.ZodObject<{
        dimensions: z.ZodObject<{
            height: z.ZodNumber;
            width: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            height: number;
            width: number;
        }, {
            height: number;
            width: number;
        }>;
    }, "strip", z.ZodTypeAny, {
        dimensions: {
            height: number;
            width: number;
        };
    }, {
        dimensions: {
            height: number;
            width: number;
        };
    }>;
}, "strip", z.ZodTypeAny, {
    data: {
        dimensions: {
            height: number;
            width: number;
        };
    };
    type: "NF::EUI_SURFACE::REQUEST_DIMENSIONS";
}, {
    data: {
        dimensions: {
            height: number;
            width: number;
        };
    };
    type: "NF::EUI_SURFACE::REQUEST_DIMENSIONS";
}>]>]>;
/**
 * `UIExtensionEvent` is a type that represents any type of event (both host and surface).
 *
 * In general, you probably don't want to use this--you're likely looking for either
 * `UIExtensionHostEvent` or `UIExtensionSurfaceEvent`.
 */
export type UIExtensionEvent = z.output<typeof UIExtensionEventSchema>;
/**
 * `UIExtensionEvent` is a union of all event `type`s (both host and surface).
 *
 * In general, you probably don't want to use this--you're likely looking for either
 * `UIExtensionHostEventType` or `UIExtensionSurfaceEventType`.
 */
export type UIExtensionEventType = UIExtensionEvent["type"];
//# sourceMappingURL=main.d.ts.map