import { z } from "zod";
import { Surfaces } from "../surfaces.js";
const CommonSDKContextSchema = z.object({
    auth: z.object({
        netlifyToken: z.string().nullable(),
        providerToken: z.string().nullable(),
    }),
    teamId: z.string().min(1),
    theme: z.enum(["light", "dark"]),
});
const TeamConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.TeamConfiguration),
    siteId: z.null(),
});
const ConnectConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.ConnectConfiguration),
    configurationId: z.string().min(1).nullable(),
    dataLayerId: z.string().min(1).nullable(),
});
const SiteAccessConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.SiteAccessConfiguration),
    siteId: z.string().min(1),
});
const SiteBuildDeployConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.SiteBuildDeployConfiguration),
    siteId: z.string().min(1),
});
const SiteGeneralConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.SiteGeneralConfiguration),
    siteId: z.string().min(1),
});
const SiteNotificationsConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.SiteNotificationsConfiguration),
    siteId: z.string().min(1),
});
const SiteConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.SiteConfiguration),
    siteId: z.string().min(1),
});
const VisualEditorConfigurationSDKContextSchema = CommonSDKContextSchema.extend({
    surface: z.literal(Surfaces.VisualEditorConfiguration),
    configurationId: z.string().min(1).nullable(),
    siteId: z.string().min(1),
});
export const SDKContextSchema = z.discriminatedUnion("surface", [
    TeamConfigurationSDKContextSchema,
    ConnectConfigurationSDKContextSchema,
    SiteAccessConfigurationSDKContextSchema,
    SiteBuildDeployConfigurationSDKContextSchema,
    SiteGeneralConfigurationSDKContextSchema,
    SiteNotificationsConfigurationSDKContextSchema,
    SiteConfigurationSDKContextSchema,
    VisualEditorConfigurationSDKContextSchema,
]);
//# sourceMappingURL=schema.js.map